@@ -418,6 +418,7 @@ namespace
             text = g_strdup_printf(_("%s (%.1f%%) of %s"), used_text, 100.0 * percent, total_text);
 
             if (cached != 0) {
+                // xgettext: Used cache string, e.g.: "Cache 2.4GiB"
                 cached_label = g_strdup_printf(_("Cache %s"), cached_text);
                 text = g_strdup_printf("%s\n%s", text, cached_label);
                 g_free (cached_label);
@@ -645,7 +646,7 @@ get_net (LoadGraph *graph)
 
     if (in >= graph->net.last_in && out >= graph->net.last_out && graph->net.time != 0) {
         float dtime;
-        dtime = time - graph->net.time;
+        dtime = (time - graph->net.time) / G_USEC_PER_SEC;
         din   = static_cast<guint64>((in  - graph->net.last_in)  / dtime);
         dout  = static_cast<guint64>((out - graph->net.last_out) / dtime);
     } else {
